summaryrefslogtreecommitdiffstats
path: root/kwin/clients/web/Web.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-19 01:42:14 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-19 01:42:14 +0000
commit8155225c9be993acc0512956416d195edfef4eb9 (patch)
treede4f3cd17614fc67e47eefabcdbe2fbe170c9be7 /kwin/clients/web/Web.cpp
parent364641b8e0279758d236af39abd138d379328a19 (diff)
downloadtdebase-8155225c9be993acc0512956416d195edfef4eb9.tar.gz
tdebase-8155225c9be993acc0512956416d195edfef4eb9.zip
Enable compilation with TQt for Qt4 3.4.0 TP2
This should not break compatibility with TQt for Qt3; if it does please fix it ASAP! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1215552 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/clients/web/Web.cpp')
-rw-r--r--kwin/clients/web/Web.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kwin/clients/web/Web.cpp b/kwin/clients/web/Web.cpp
index 43d1b9f42..9b5e434da 100644
--- a/kwin/clients/web/Web.cpp
+++ b/kwin/clients/web/Web.cpp
@@ -120,31 +120,31 @@ KCommonDecorationButton *WebClient::createButton(ButtonType type)
{
switch (type) {
case MenuButton:
- return new WebButton(MenuButton, this, "menu", shape_);
+ return new WebButton(MenuButton, this, "menu", tqshape_);
case OnAllDesktopsButton:
- return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", shape_);
+ return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", tqshape_);
case HelpButton:
- return new WebButton(HelpButton, this, "help", shape_);
+ return new WebButton(HelpButton, this, "help", tqshape_);
case MinButton:
- return new WebButton(MinButton, this, "minimize", shape_);
+ return new WebButton(MinButton, this, "minimize", tqshape_);
case MaxButton:
- return new WebButton(MaxButton, this, "maximize", shape_);
+ return new WebButton(MaxButton, this, "maximize", tqshape_);
case CloseButton:
- return new WebButton(CloseButton, this, "close", shape_);
+ return new WebButton(CloseButton, this, "close", tqshape_);
case AboveButton:
- return new WebButton(AboveButton, this, "above", shape_);
+ return new WebButton(AboveButton, this, "above", tqshape_);
case BelowButton:
- return new WebButton(BelowButton, this, "below", shape_);
+ return new WebButton(BelowButton, this, "below", tqshape_);
case ShadeButton:
- return new WebButton(ShadeButton, this, "shade", shape_);
+ return new WebButton(ShadeButton, this, "shade", tqshape_);
default:
return 0;
@@ -185,7 +185,7 @@ WebClient::init()
KConfig c("kwinwebrc");
c.setGroup("General");
- shape_ = c.readBoolEntry("Shape", true);
+ tqshape_ = c.readBoolEntry("Shape", true);
KCommonDecoration::init();
}
@@ -195,8 +195,8 @@ WebClient::reset( unsigned long changed )
{
if (changed & SettingColors)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
} else if (changed & SettingFont) {
// font has changed -- update title height
// title height
@@ -206,7 +206,7 @@ WebClient::reset( unsigned long changed )
if (0 != titleHeight_ % 2)
titleHeight_ += 1;
- widget()->repaint(false);
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -216,7 +216,7 @@ WebClient::reset( unsigned long changed )
WebClient::paintEvent(TQPaintEvent * pe)
{
int r_x, r_y, r_x2, r_y2;
- widget()->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
+ TQT_TQRECT_OBJECT(widget()->rect()).coords(&r_x, &r_y, &r_x2, &r_y2);
const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
@@ -231,7 +231,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
TQPainter p(widget());
p.setPen(Qt::black);
- p.setBrush(options()->colorGroup(ColorFrame, isActive()).background());
+ p.setBrush(options()->tqcolorGroup(ColorFrame, isActive()).background());
p.setClipRegion(pe->region() - titleRect);
@@ -241,7 +241,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
p.fillRect(titleRect, options()->color(ColorTitleBar, isActive()));
- if (shape_)
+ if (tqshape_)
{
int r(width());
int b(height());
@@ -288,7 +288,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
void WebClient::updateWindowShape()
{
- if (!shape_)
+ if (!tqshape_)
return;
TQRegion mask(0, 0, width(), height());